//----------------------------------------------------------------
// Afocal
//
//  - An afocal photography phone holder
//
//  21Oct2021 A.Cooper
//  - initial version
//
//----------------------------------------------------------------

//-- constants ---------------------------------------------------
mSteps=50;
cSteps=50;

assembly=false;
platform=false;
slide=   true;
phone=   false;
fast=    true;

//-- modules for each part ---------------------------------------

module phone(){
  color("Silver",0.5)
    translate([0,0,1])
      cylinder(d=10,h=2,center=true,$fn=steps);
  color("DimGray",0.4)
    translate([-58.5,23,6])
      cube([145,74,12],center=true);
  }
  
module platform(){
 translate([0,0,2.5]){
   difference(){
     // body plate
     if (fast)
       difference(){
         translate([20,20,0])
           cube([110,110,5],center=true);
         // optical opening
         cylinder(d=35,h=20,center=true,$fn=cSteps);
         }
     else
       minkowski(){
         difference(){
           translate([20,20,0])
             cube([110,110,1],center=true);
           // optical opening
           cylinder(d=35,h=20,center=true,$fn=cSteps);
           }
         sphere(r=2,$fn=mSteps);
         }
     // steel plate inset
     translate([50,20,-1.9])
       cube([40,100,2],center=true);
     translate([20,50,-1.9])
       cube([100,40,2],center=true);
     }
   // eyepiece socket
   translate([0,0,14])
     difference(){
       cylinder(d=60,h=23,center=true,$fn=cSteps);
       cylinder(d=54,h=24,center=true,$fn=cSteps);
       }
   // grip ridges
   translate([27,0,14])
     cylinder(d=1,h=23,center=true,$fn=cSteps);
   translate([-27,0,14])
     cylinder(d=1,h=23,center=true,$fn=cSteps);
   translate([0,27,14])
     cylinder(d=1,h=23,center=true,$fn=cSteps);
   translate([0,-27,14])
     cylinder(d=1,h=23,center=true,$fn=cSteps);
   }
 }
 
module slide(){
  difference(){
    minkowski(){
      union(){
        //bottom plate
        difference(){
          translate([0,0,3])
            cube([116,71,2],center=true);
          translate([-40,20,0])
            cube([60,60,12],center=true);
          }
        //upright
        difference(){
          translate([0,-33,10])
            cube([116,5,16],center=true);
          translate([0,-25,12])
            rotate([0,90,0])
              cylinder(d=20,h=150,center=true,$fn=cSteps);
          }
        }
      sphere(r=2,$fn=cSteps);
      }
    // magnets
    translate([15,-20,0])
      cylinder(d=18.5,h=4,center=true,$fn=cSteps);
    translate([-30,-20,0])
      cylinder(d=18.5,h=4,center=true,$fn=cSteps); 
    translate([15,20,0])
      cylinder(d=18.5,h=4,center=true,$fn=cSteps);
    // nameplate
    translate([-2,0,6])
      rotate([0,0,0])
        linear_extrude(height=1,center=true){
          translate([0,10,0])
            text("Magfocal",font="MV Boli",size=6,halign="left");
          translate([0,0,0])
            text("www.DarkerView.com",font="MV Boli",size=4,halign="left");
          }
    }    
  }
  
//-- instantiate -------------------------------------------------

if (assembly){
  translate([0,0,6])
    rotate([0,0,90])
      phone();
  color("DimGray",0.5)
    rotate([0,180,90])
      platform();
  translate([-30,-30,0])
    rotate([0,0,-90])
      slide();
  }
else{
  if (phone)
    phone();
  if (platform)
    platform();
  if (slide)
    slide();
  }
    
//-- end ---------------------------------------------------------